data = xlsread('mpddata.xlsx', 'Input');             % Reads input matrix
n = size(data);                                      % Finds the size of the input matrix
n = n(1);                                            % Finds the number of rows (n)
t = data(1:n,3)*60*60*24;                            % Finds time time matrix and convert values from days to seconds
h = data(1:n,2);                                     % Finds head matrix

dteta=data(2,1)-data(1,1);                            % Finds differences in volumetric water content (dteta)
Lmax = data(3,1);                                     % Finds length of device below surface
rd = data(4,1);                                       % Finds radius of device
H = data(5,1);                                        % Finds phase one initial height
K = 0.001;
C = -1000;

tt(1,1)=0;                                           % Sets first intermediate time value to zero
i=2:n;                                               % Prepare integers for the remaining intermediate time values
tt(i,1)= (t(i,1)-t(i-1,1))*0.5+t(i-1,1);             % Finds intermediate time values (tt)
hh = spline(t,h,tt);                                 % Cubic spline interpolation to find intermediate h values (hh)

q(1,1)=0;                                            % Sets first difference value to zero
qt(1,1)=0;                                           % Sets first time difference value to zero
qh(1,1)=0;                                           % Sets first head difference value to zero

i = 2:n;                                             % Prepare integers for the remaining intermediate time values
qt(i,1) = tt(i,1)-tt(i-1,1);                         % Fills in remaining time difference values (qt)
qh(i,1) = hh(i,1)-hh(i-1,1);                         % Fills in remaining head difference values (qh)

for i=2:n,                                           % Calculate difference values (q)
 
    q(i,1)=qh(i,1)/qt(i,1);
    
end

i=1;
while(i<n+1)                                         % Using Newton-Rhapson to find R values
    x = 1;
    ii = 1;
    
    while(ii<100000)
    
    f1=2*x^3+Lmax*3*x^2-Lmax^3-2*(rd/2)^3-3*rd^2*(H-hh(i,1))/(dteta);
    ff = 6*x^2+Lmax*6*x;
    x = x-f1/ff;
    ii =ii +1;
    R(i,1)=x;
    
    end
i=i+1;
end


for i=2:n,                                           % Calculate difference values (q)
 
    q(i,1)=qh(i,1)/qt(i,1);
    
end
      
i = 1;
while(i<n+1)  
    if R(i,1)<(Lmax^2+rd^2)^0.5, R(i,1)=0;           % Calculate R values (R)
    end
    i=i+1;
end



i = 2:n;                                             % Prepare integers for the remaining intermediate time values
dt1(i,1)=tt(i,1)-tt(i-1,1);                          % Fills in remaining time difference values (qt)




for i=1:n,                                           
    if R(i,1)<10^-10, ss=i;           % Calculate R values (R)
    end
end



KC0 = [0.01,-100];
f = @(KC)optt(KC,n,Lmax,dteta,R,rd,hh,dt1,ss);
[KC,f] = fminsearch(f,KC0);

Results(1,1)=KC(1);
Results(1,2)=KC(1)*60^2;
Results(1,3)=KC(2);
Results(1,4)=f;
Results(1,5)=n-ss-1;
Results(1,6)=sqrt(f/(n-ss-1));


i = 2:n;                                             % Prepare integers for the remaining intermediate time values
dh1(i,1)=-hh(i,1)+hh(i-1,1);                          % Fills in remaining time difference values (qt)

KC0 = [0.01,-100];
f = @(KC)opth(KC,n,Lmax,dteta,R,rd,hh,tt,dh1,ss);
[KC,f] = fminsearch(f,KC0);

Results(2,1)=KC(1);
Results(2,2)=KC(1)*60^2;
Results(2,3)=KC(2);
Results(2,4)=f;
Results(2,5)=n-ss-1;
Results(2,6)=sqrt(f/(n-ss-1));


'Estimated parameters:'

format shortG

ForExcelSheet(1,1)=Results(1,1);
ForExcelSheet(2,1)=Results(1,2);
ForExcelSheet(3,1)=Results(1,3);
ForExcelSheet(4,1)=Results(1,4);
ForExcelSheet(5,1)=Results(1,5);
ForExcelSheet(6,1)=Results(1,6);
ForExcelSheet(7,1)=Results(2,1);
ForExcelSheet(8,1)=Results(2,2);
ForExcelSheet(9,1)=Results(2,3);
ForExcelSheet(10,1)=Results(2,4);
ForExcelSheet(11,1)=Results(2,5);
ForExcelSheet(12,1)=Results(2,6);

ForExcelSheet

disp('    Ksat[cm/s]      Ksat[cm/h]  Cap.Suc.[cm]   Sum of error    Obs.    RMS error')

disp(Results)

if Results(1,4)<Results(2,4), 'Delta T optimization gives smallest error:'
else 'Delta H optimization gives smallest error: '
end

if Results(1,4)<Results(2,4), Ksat=Results(1,2)
else Ksat=Results(2,2)
end

if Results(1,4)<Results(2,4), C=Results(1,3)
else C=Results(2,3)
end

